Range-v3: range/v3/view/view.hpp File Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Classes | Typedefs | Variables
view.hpp File Reference

## Classes
struct | ranges::v3::view::make_view_fn
struct | ranges::v3::view::view< View >
struct | ranges::v3::view::view_access
struct | ranges::v3::view::view_access::impl< View >

## Typedefs
template<typename Rng >
using | ranges::v3::view::ViewableRange = meta::and_< Range< Rng >, meta::or_< std::is_lvalue_reference< Rng >, View< uncvref_t< Rng > >> >

## Variables
constexpr make_view_fn | ranges::v3::view::make_view {}